#!/usr/bin/env python

import os
import sys
from struct import pack

import tml
from tml.tml import Teemap
from tml.items import Tile, TileLayer, TileManager

# check tml version
if tml.get_version() < '0.2.2':
    raise Exception('Please update tml to version 0.2.2 or newer')

def convert(filename):
    filedir, mapname = os.path.split(filename)
    mapname = os.path.splitext(mapname)[0]
    t = Teemap(filename)

    # check if the map already has a tele layer
    if t.telelayer:
        raise TypeError('map already has a tele layer')

    # check for old tele tiles
    gamelayer = t.gamelayer
    has_teleporter = False
    for tile in gamelayer.tiles:
        if tile.index >= 35 and tile.index <= 84:
            has_teleporter = True
            break
    if not has_teleporter:
        raise TypeError('map does not have any teleports')

    # get the gamegroup and add telelayer
    for group in t.groups:
        for layer in group.layers:
            if layer.is_gamelayer:
                tele_tiles = TileManager(size=gamelayer.width*gamelayer.height, _type=2)
                tele_tiles.tiles = ['\x00\x00'] * gamelayer.width*gamelayer.height
                group.append(TileLayer(gamelayer.width, gamelayer.height,
                                       name='Tele', game=2, tele_tiles=tele_tiles))

    # get gamelayer and layer number for later
    telelayer = t.telelayer
    for i, tile in enumerate(gamelayer.tiles):
        if tile.index >= 35 and tile.index <= 84:
            tele_number = ((tile.index-35)/2)+1
            telelayer.tele_tiles.tiles[i] = pack('2B', tele_number, 26 if tile.index % 2 == 0 else 27)
            tile = Tile()
            gamelayer.tiles[i] = tile

    # change name of gamelayer to Game (tml fail)
    gamelayer.name = 'Game'

    # save the map
    t.save(os.path.join(filedir, '{0}_new'.format(mapname)))

if __name__ == '__main__':
    for filename in sys.argv[1:]
        try:
            convert(filename)
        except TypeError, e:
            print '{0}: {1}'.format(filename, e)

